==> dif-database-repository-2.1.9-1-20151124.173937-3-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ECommerceServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.IECommerceService;
import pt.digitalis.dif.dem.managers.impl.model.dao.IEcommercePaymentsDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.impl.EcommercePaymentsDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.EcommercePayments;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class ECommerceServiceImpl implements IECommerceService {

	/**
	 * Obtains a new EcommercePayments DAO
	 *
	 * @return A new IEcommercePaymentsDAO
	 */
    public IEcommercePaymentsDAO getEcommercePaymentsDAO() {
    	return new EcommercePaymentsDAOImpl();
    }

    /**
     * Obtains a new DataSet for the EcommercePayments entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<EcommercePayments> getEcommercePaymentsDataSet() {
        return new HibernateDataSet<EcommercePayments>(EcommercePayments.class, new EcommercePaymentsDAOImpl(),
                EcommercePayments.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == EcommercePayments.class)
            return getEcommercePaymentsDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(EcommercePayments.class.getSimpleName()))
            return getEcommercePaymentsDataSet();

        return null;
    }
}

==> dif-database-repository-2.1.9-12-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ECommerceServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.IECommerceService;
import pt.digitalis.dif.dem.managers.impl.model.dao.IEcommercePaymentsDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.impl.EcommercePaymentsDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.EcommercePayments;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class ECommerceServiceImpl implements IECommerceService {

    /**
     * Obtains a new EcommercePayments DAO
     *
     * @return A new IEcommercePaymentsDAO
     */
    public IEcommercePaymentsDAO getEcommercePaymentsDAO()
    {
        return new EcommercePaymentsDAOImpl();
    }

    /**
     * Obtains a new DataSet for the EcommercePayments entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<EcommercePayments> getEcommercePaymentsDataSet()
    {
        return new HibernateDataSet<EcommercePayments>(EcommercePayments.class, new EcommercePaymentsDAOImpl(),
                EcommercePayments.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz)
    {

        if (clazz == EcommercePayments.class)
            return getEcommercePaymentsDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName)
    {

        if (entityName.equalsIgnoreCase(EcommercePayments.class.getSimpleName()))
            return getEcommercePaymentsDataSet();

        return null;
    }
}
